"""Constants for FusionSolar Kiosk."""

# Fusion Solar Kiosk API response attributes
ATTR_DATA = "data"
ATTR_FAIL_CODE = "failCode"
ATTR_SUCCESS = "success"
ATTR_DATA_REALKPI = "realKpi"
# Data attributes
ATTR_REALTIME_POWER = "realTimePower"
ATTR_TOTAL_CURRENT_DAY_ENERGY = "dailyEnergy"
ATTR_TOTAL_CURRENT_MONTH_ENERGY = "monthEnergy"
ATTR_TOTAL_CURRENT_YEAR_ENERGY = "yearEnergy"
ATTR_TOTAL_LIFETIME_ENERGY = "cumulativeEnergy"


# Possible ID suffixes
ID_REALTIME_POWER = "realtime_power"
ID_TOTAL_CURRENT_DAY_ENERGY = "total_current_day_energy"
ID_TOTAL_CURRENT_MONTH_ENERGY = "total_current_month_energy"
ID_TOTAL_CURRENT_YEAR_ENERGY = "total_current_year_energy"
ID_TOTAL_LIFETIME_ENERGY = "total_lifetime_energy"


# Possible Name suffixes
NAME_REALTIME_POWER = "Realtime Power"
NAME_TOTAL_CURRENT_DAY_ENERGY = "Total Current Day Energy"
NAME_TOTAL_CURRENT_MONTH_ENERGY = "Total Current Month Energy"
NAME_TOTAL_CURRENT_YEAR_ENERGY = "Total Current Year Energy"
NAME_TOTAL_LIFETIME_ENERGY = "Total Lifetime Energy"



import asyncio

from fhempy.lib.fusionsolar.fusionsolar_api import FusionSolarKioksApi

from .. import fhem, utils
from ..generic import FhemModule


class fusionsolar(FhemModule):
    def __init__(self, logger):
        super().__init__(logger)

        attr_config = {
            "interval": {
                "default": 300,
                "format": "int",
                "help": "Change interval, default is 300.",
            }
        }
        self.set_attr_config(attr_config)

    # FHEM FUNCTION
    async def Define(self, hash, args, argsh):
        await super().Define(hash, args, argsh)
        if len(args) > 3:
            return "Usage: define my_solar PythonModule fusionsolar <KIOSKKEY>"
        self._kioskkey = args[3]
        await fhem.readingsBeginUpdate(hash)
        await fhem.readingsBulkUpdateIfChanged(hash, "state", "ready")
        await fhem.readingsEndUpdate(hash, 1)
        self.create_async_task(self.update())

    async def update(self):
        api = FusionSolarKioksApi("https://eu5.fusionsolar.huawei.com")
        data = await utils.run_blocking(api.getRealTimeKpi, self._kioskkey)

        return data
